#
# spec file for package scribus
#
# Copyright (c) 2020 SUSE LLC
# Copyright (c) Peter Linnell and 2010 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           scribus
Version:        1.5.6.1
Release:        bp153.1.16
Summary:        Page Layout and Desktop Publishing (DTP)
License:        GPL-2.0-or-later
Group:          Productivity/Publishing/Other
URL:            https://www.scribus.net/
# https://sourceforge.net/projects/scribus/files/scribus-devel/1.5.6.1/
Source:         %{name}-%{version}.tar.xz
# PATCH-FIX-OPENSUSE
Patch0:         0001-Make-sure-information-displayed-on-the-about-window-.patch
BuildRequires:  cmake >= 3.12.0
BuildRequires:  cups-devel
BuildRequires:  dos2unix
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  libboost_headers-devel
BuildRequires:  libcdr-devel
BuildRequires:  libfreehand-devel
BuildRequires:  libmspub-devel
BuildRequires:  libpagemaker-devel
BuildRequires:  libpodofo-devel
BuildRequires:  libqxp-devel
BuildRequires:  librevenge-devel
BuildRequires:  libtiff-devel
BuildRequires:  libvisio-devel
BuildRequires:  libwpd-devel
BuildRequires:  libwpg-devel
BuildRequires:  libzmf-devel
BuildRequires:  pkgconfig
BuildRequires:  python3-devel
BuildRequires:  update-desktop-files
BuildRequires:  cmake(Qt5Core) >= 5.11.0
BuildRequires:  cmake(Qt5Gui) >= 5.11.0
BuildRequires:  cmake(Qt5LinguistTools) >= 5.11.0
BuildRequires:  cmake(Qt5Network) >= 5.11.0
BuildRequires:  cmake(Qt5OpenGL) >= 5.11.0
BuildRequires:  cmake(Qt5PrintSupport) >= 5.11.0
BuildRequires:  cmake(Qt5Widgets) >= 5.11.0
BuildRequires:  cmake(Qt5Xml) >= 5.11.0
BuildRequires:  pkgconfig(GraphicsMagick)
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(harfbuzz)
BuildRequires:  pkgconfig(hunspell)
BuildRequires:  pkgconfig(icu-i18n)
BuildRequires:  pkgconfig(icu-uc)
BuildRequires:  pkgconfig(lcms2)
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(poppler)
BuildRequires:  pkgconfig(zlib)
Requires:       hicolor-icon-theme
Recommends:     python3-Pillow
Recommends:     python3-tk
# Only available in graphics for the moment
Recommends:     uniconvertor
Recommends:     scribus-doc

# Not packaged anymore
Provides:       scribus-devel = %{version}
Obsoletes:      scribus-devel < %{version}

%description
Scribus is a page layout program which produces output in PDF and
Postscript.

Scribus supports publishing features such as CMYK and spot colors,
PDF creation, Encapsulated Postscript import and export and creation
of color separations.

%package doc
Summary:        Documentation for Scribus
Group:          Documentation/HTML

%description doc
This package provides the documentation for Scribus.

%prep
%setup -q
# W: wrong-script-end-of-line-encoding
# also required for cherry-picked patches
find . -type f \( -iname \*.py -o -iname \*.cpp -o -iname \*.h \) -exec dos2unix {} \;

%autopatch -p1

%build
# Don't use the %%cmake macro, it causes crashes when starting scribus
mkdir build
pushd build
cmake .. \
  -DCMAKE_INSTALL_PREFIX=%{_prefix} \
  -DWANT_DISTROBUILD=1 \
  -DWANT_HUNSPELL=1 \
  -DWANT_GRAPHICSMAGICK=1 \
%if "%{_lib}" == "lib64"
  -DWANT_LIB64=1
%endif

%cmake_build
popd

%install
%cmake_install

# These files are required at runtime to populate the help/about window
mkdir -p %{buildroot}%{_datadir}/scribus/aboutData
mv %{buildroot}%{_datadir}/doc/scribus/{AUTHORS,COPYING,LINKS,TRANSLATION} %{buildroot}%{_datadir}/scribus/aboutData/

# Already in %%doc
rm -f %{buildroot}%{_datadir}/doc/scribus/{ChangeLog,README}

%fdupes %{buildroot}%{_datadir}/doc/scribus
%fdupes %{buildroot}%{_datadir}/scribus

%suse_update_desktop_file -r scribus Qt Office WordProcessor

%files doc
%license COPYING
%doc ChangeLog README
%dir %{_datadir}/doc/scribus/
%lang(de) %{_datadir}/doc/scribus/de/
%lang(it) %{_datadir}/doc/scribus/it/
%lang(ru) %{_datadir}/doc/scribus/ru/
%{_datadir}/doc/scribus/en/

%files
%license COPYING
%doc ChangeLog README
%dir %{_datadir}/doc/scribus/
%dir %{_datadir}/icons/hicolor/1024x1024
%dir %{_datadir}/icons/hicolor/1024x1024/apps
%lang(de) %dir %{_mandir}/de
%lang(de) %dir %{_mandir}/de/man1
%lang(de) %{_mandir}/de/man1/scribus.1%{?ext_man}
%lang(pl) %dir %{_mandir}/pl
%lang(pl) %dir %{_mandir}/pl/man1
%lang(pl) %{_mandir}/pl/man1/scribus.1%{?ext_man}
%{_bindir}/scribus
%{_datadir}/applications/scribus.desktop
%{_datadir}/icons/hicolor/*/apps/scribus.png
%{_datadir}/metainfo/scribus.appdata.xml
%{_datadir}/mime/packages/scribus.xml
%{_datadir}/scribus/
%{_libdir}/scribus/
%{_mandir}/man1/scribus.1%{?ext_man}

%changelog
* Sun Nov 15 2020 Wolfgang Bauer <wbauer@tmo.at>
- Update to 1.5.6.1
  * Fix a spell checker crash
* Wed Nov 11 2020 Wolfgang Bauer <wbauer@tmo.at>
- Update to 1.5.6
  * User Interface:
    + One of the most important changes compared to earlier
    versions is the introduction of a context-sensitive Content
    Palette. If set to visible, it will adjust to the kind of
    item (text frame, image frame, table, group) you have
    selected.
    + Ctrl/Cmd+Click enables selecting items below guides.
    + A new PDF-based output preview is now available.
    + Support for dark UI themes has been improved.
    + Icon set can now be changed without needing to restart
    application
    + It's now possible to "cycle" through the items in a group by
    pressing Alt+Ctrl/Cmd+Click
  * Import/Export:
    + Support for PDF 1.6 export, including embedded OpenType
    fonts.
    + A Markdown import filter has been added.
    + Improvements to the IDML, PDF, XTG, SVG and KRA importers.
  * Text and Typography:
    + Launching Scribus via the Command Line on any OS will now
    reveal more font-related problems; based on fontconfig 3.14.
  * Colors:
    + Default black and white colors can now alternatively be
    defined in RGB and LAB.
  * Printing:
    + With the exception of the Windows platform, Scribus can now
    use a PDF-based and newly written printing engine. PostScript
    is still available, but will be removed over time.
  * Scripter:
    + On platforms other than macOS, Scribus now uses Python 3 by
    default. As a consequence, existing scripts will likely need
    to be modified so that they run in Scribus 1.5.6.
    + Many new commands have been added to the Scripter; others
    have been renamed to be more intuitive. For more information,
    please have a look at the Scripter documentation, which has
    also been updated to reflect the changes.
- Drop patches merged upstream:
  * port-scripter-to-Python-3.patch
  * Work-around-poppler-0.82-signature-changes.patch
  * Use-same-mechanism-as-with-previous-poppler-versions.patch
  * Fix-failure-to-build-against-poppler-0.83.0.patch
  * Fix-failure-to-build-with-poppler-0.84.0.patch
  * Fails-to-build-with-python-3.8.patch
  * 0001-PDF-import-plugin-support-poppler-0.86.x.patch
  * 0001-Fix-build-with-Qt-5.15.patch
- Add _constraints with a minimum disk size of 5GB, to avoid build
  failures due to insufficient disk space
- Remove -DWANT_RELEASEWITHDEBUG=1 cmake option again, it causes
  loading the plugins to fail due to unresolved symbols, and
  possibly a crash on start
* Thu Sep 17 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Depend on hicolor-icon-theme for directory structure
- Enable proper debuginfo/debugsource creation
- Spec file cleanup
  * Remove unused libetonyek and GraphicsMagick++ build dependencies
  * Do not install breeze SVG icon into pixmap directory, drop
    breeze-icons dependency
  * Remove conditionals for obsolete distro versions
* Sat May  9 2020 Wolfgang Bauer <wbauer@tmo.at>
- Add 0001-Fix-build-with-Qt-5.15.patch to fix build with the
  upcoming Qt 5.15
* Wed Apr  8 2020 Christophe Giboudeaux <christophe@krop.fr>
- Add upstream patch:
  * 0001-PDF-import-plugin-support-poppler-0.86.x.patch
- Update:
  * Fix-failure-to-build-against-poppler-0.83.0.patch
  * Fix-failure-to-build-with-poppler-0.84.0.patch
  * Use-same-mechanism-as-with-previous-poppler-versions.patch
  * Work-around-poppler-0.82-signature-changes.patch
  * port-scripter-to-Python-3.patch
* Thu Jan 16 2020 Wolfgang Bauer <wbauer@tmo.at>
- Add port-scripter-to-Python-3.patch and build with python3
- Add patches to fix build with newer poppler versions:
  * Work-around-poppler-0.82-signature-changes.patch
  * Use-same-mechanism-as-with-previous-poppler-versions.patch
  * Fix-failure-to-build-against-poppler-0.83.0.patch
  * Fix-failure-to-build-with-poppler-0.84.0.patch
- Add Fails-to-build-with-python-3.8.patch to fix build with python
  3.8
* Mon Sep  9 2019 Jan Engelhardt <jengelh@inai.de>
- Drop faulty requires from documentation subpackage.
* Fri Aug  9 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 1.5.5:
  * Development version using Qt5.
  * Large code refactoring
  * Many bugs fixed
- Check https://wiki.scribus.net/canvas/1.5.5_Release for more information
- Drop hunspell.patch
- Add 0001-Make-sure-information-displayed-on-the-about-window-.patch
* Sat Nov 24 2018 Fabian Vogt <fabian@ritter-vogt.de>
- Rewrite hunspell-1.6.patch into hunspell.patch to cover all hunspell
  versions
* Sat Nov 24 2018 wbauer@tmo.at
- Update hunspell-1.6.patch to also accept hunspell 1.7 that's in
  Factory now
* Wed May 30 2018 jengelh@inai.de
- Trim marketing filler wording from description.
- Replace duplicate -fno-strict-aliasing.
- Run fdupes over more files. (Do it with hardlinks;
  symlinks upset the documentation system.)
* Tue May  1 2018 wbauer@tmo.at
- Add back hunspell-1.6.patch, it's still needed as the current
  version still only supports hunspell up to 1.4 but Tumbleweed and
  Leap 15.0 have 1.6
* Sun Apr 29 2018 plinnell@opensuse.org
- drop hunspell-1.6.patch fixed uptream
- lots of spec file cleanups
* Sat Apr 28 2018 plinnell@opensuse.org
- Update to 1.4.7 - likely last release from 1.4.x stable branch
- Stability and bugfix release
- Updated UI translations
- See: https://bugs.scribus.net/changelog_page.php?version_id=96
  for complete list.
* Tue Mar 27 2018 wbauer@tmo.at
- Add hunspell-1.6.patch to fix spellchecking support in Tumbleweed
  and Leap 15.0
* Thu Jan  4 2018 wbauer@tmo.at
- remove libQtWebKit-devel build requirement, it seems not to be
  used/needed at all
* Fri Aug 11 2017 pgajdos@suse.com
- remove dependency on aspell, scribus seem to use hunspell
  [bsc#1052965]
* Thu Feb  2 2017 adam.majer@suse.de
- use individual libboost-*-devel packages instead of boost-devel
* Tue Nov 15 2016 wbauer@tmo.at
- Use shared-mime-info macros (boo#979301)
- Remove version check for > 11.3, earlier versions are not
  supported any more
* Wed Aug 10 2016 badshah400@gmail.com
- Fixup scribus.appdata.xml file
  + Shorten name to just "scribus".
  + Use images from github repository as appstream fails to load
    images from https://wki.scribus.net.
  + Improve a caption.
  + Fix height of screenshot 2.
* Thu Jul 28 2016 badshah400@gmail.com
- Add scribus.appdata.xml file and install it to the appdata dir;
  this makes scribus appear in appstores like GNOME Software and
  KDE Discover.
* Fri Mar 18 2016 alarrosa@suse.com
- Added an fdupes call to symlink duplicate files installed
  under /usr/share/. This reduces the installed size in around 20 Mb.
* Mon Jan 11 2016 plinnell@opensuse.org
- Update to 1.4.6
  + See http://bugs.scribus.net/changelog_page.php?version_id=92
* Thu May 29 2014 plinnell@opensuse.org
- Update to 1.4.4
- Drop python-version.diff it is upstream.
  + PDF/X-1a export.
  + The Barcode plug-in has been updated to reflect
  the latest changes in the underlying Barcode Writer
  in Pure PostScript (BWIPP).
  + The Autoquote script has been rewritten and enhanced.
  It now provides more options and adds thin spaces to French texts
  where appropriate.
  + A script to align images in frames has been added.
  + Full support of the OpenICC Directory Proposal
  (http://www.oyranos.org/wiki/index.php?title=OpenIccDirectoryProposal).
  + The handling of transparencies in Photoshop-generated TIFF files
  has been improved.
  + Page borders can now act as guides (and thus be used for
  snapping of items).
  + The CMYK color palette created by the Newspaper Association
  of America  (NAA) for newspaper advertisements has been
  integrated into Scribus.
  + A new color palette for professional geographers has been added.
  + Export to various bitmap formats has been re-enabled on Mac OS X.
  + Several issues related to the user interface and canvas display
  have been resolved.
  + Adjustments for Windows 8.x.
  + An issue with the spellchecker, resulting in a crash,
  has been resolved.
  + Documentation and translation updates and improvements.
  +For a complete list of changes see:
  http://bugs.scribus.net/view_all_bug_page.php?filter=99610
  and http://lists.scribus.net/pipermail/scribus-commit.
* Thu Apr 17 2014 hrvoje.senjan@gmail.com
- Added python_version.diff: fixes build with cmake 3.0
* Thu Aug 22 2013 mrdocs@opensuse.org
- Update to version 1.4.2
  + The Barcode Writer has been updated and supports many more
    barcodes, including QR.
  + The Galaxy Gauge™ color matching system and color tools have
    been included.
  + New color palettes from government agencies (Canada,
    Germany, The Netherlands, United Kingdom) have been included.
  + More Open Source color palettes have been included.
  + Improvements to the build system.
  + Improvements to the Preflight Verifier.
  + The A4 page size limit of TeX-rendered graphics in Render
    Frames has been removed.
  + The Short Words plug-in now supports Danish.
  +  Many updates to the Online Manual.
-  Most important bugfixes:
- Disabled hyphenation on some Linux distributions is working again.
- Some unit conversion issues have been fixed.
- Display issues related to Ubuntu's Unity interface have been fixed.
- Some fixes to wrong or irritating UI behavior.
- Memory management in connection with the new Hyphenator has
  been optimized.
- Issues with the Clang compiler have been fixed.
- Scribus now supports Pillow as an alternative to the Python Imaging Library.
- Many translation updates.
* Mon Jan 14 2013 mrdocs@opensuse.org
- Update to version 1.4.2:
  - New feature - hunspell based spell checker
  - UI and Document Updates and translation updates
  - Scribus will look for existing dictionaries on the system
    it is installed already installed by hunspell packages or
    LibreOffice. New dictionaries are downloadable directly from
    within Scribus Preferences via freedesktop.org.
    The spellchecker now also works within the Story Editor.
  - Stability and other minor fixes
  - Complete versioned changelog:
    http://bugs.scribus.net/changelog_page.php?version_id=84
* Fri Jul  6 2012 dmueller@suse.com
- fix build for older distros
* Mon Jun 25 2012 badshah400@gmail.com
- Install hi-res icons in the hicolor icon directory for better
  appearance on desktop menu, specifically on the gnome-shell; add
  BuildRequires: hicolor-icon-theme for this purpose.
* Wed May 23 2012 badshah400@gmail.com
- Delete non-free colour swatches (givelife and dtp-studio) from
  the package (bnc#763586)
* Wed May 23 2012 mrdocs@opensuse.org
- drop fdupes in %%datashare it breaks the help browser
- shorten the -devel description
* Mon May 21 2012 badshah400@gmail.com
- Add back aspell and liblcms2-devel BuildRequires: these got
  removed during the previous change by mistake.
* Sat May  5 2012 badshah400@gmail.com
- Update to version 1.4.1:
  + Many bugs fixed since 1.4.0 (see ChangeLog file installed in
    /usr/share/doc/scribus/)
  + Addition of the GiveLife Color System(R) swatch palettes
    (www.givelifecolorsystem.com), license in the swatches
    directory.
  + Updates to resolve small canvas interaction issues
  + Corrections to both bitmap and SVG image import issues
  + Addition of undo steps for path operations and page moving
  + Corrections to some master page behaviour
  + Fixes for text editing issues
  + Enhancements to scripter
  + Translation updates
  + The Italian version of the help documents has been updated
    significantly
  + Relocation of profiles and swatches to the share directory of
    Unix-like systems (linux, OS X, etc) to fit in with the file
    system recommendations
- Added build requirement on fdupes to link duplicate files
- Install desktop menu for application
- Changes from version 1.4.0:
  + Many bugs fixed since 1.4.0rc6 (see ChangeLog file installed
    in /usr/share/doc/scribus/).
* Fri Jan 20 2012 toddrme2178@gmail.com
- Fixed aspell detection
- Added lcms2 buildrequires
* Mon Jan  2 2012 adrian@suse.de
- update to final 1.4.0 release
- use xz compressed tar ball
* Tue Dec  6 2011 coolo@suse.com
- scribus is GPL-2.0+
* Wed Oct 26 2011 coolo@suse.com
- merged KDF again
* Wed Oct 19 2011 mrdocs@opensuse.org
-updated to 1.4.0.rc6
-last RC before 1.4.0 final
  +documentation updates, bug fixes and translation updates
  +http://scribus.net/svn/Scribus/branches/Version135/Scribus/ChangeLog
  for versioned changelog
* Mon Aug 15 2011 idonmez@novell.com
- Fix build and use %%{_smp_mflags}
* Wed Aug 10 2011 toddrme2178@gmail.com
- Fixed language file identification
  - Removed redundant buildrequires
  - Cleaned up spec file formatting
* Sat Jun 18 2011 mrdocs@opensuse.org
-update to 1.4.0.rc5
  + more bug fixes and translation updates
  see http://bugs.scribus.net/changelog_page.php?version_id=68
  for versioned changelog
* Sun Apr 10 2011 mrdocs@opensuse.org
-update to 1.4.0.rc3
  + more bug fixes and translation updates
  see http://bugs.scribus.net/changelog_page.php?version_id=68
  for versioned changelog
* Tue Mar  8 2011 mrdocs@opensuse.org
-update to 1.4.0.rc2
  + more bug fixes and translation updates
  see http://bugs.scribus.net/changelog_page.php?version_id=68
  for versioned changelog
* Fri Feb 18 2011 mrdocs@opensuse.org
-remove some old versioning cruft from spec file
* Fri Feb 18 2011 mrdocs@opensuse.org
- update to 1.4.0.rc1 1.4.0 is new stable branch
  +40+ bugs fixed see:
  http://bugs.scribus.net/changelog_page.php?version_id=68 for
  versioned change log details
- Add Obsoletes/Provides for scribus-templates for those upgrading
  from 1.3.3.14, former stable.  1.4.0 has new
  and many additional templates included by default
* Sat Jan 15 2011 mrdocs@opensuse.org
- disable parallel build by removing %%jobs macro, it caused OOMs
  during build.
* Mon Dec 27 2010 dmueller@suse.de
- fix build
* Tue Dec 14 2010 mrdocs@opensuse.org
- spec file clean-ups from darix and remove all non-Suse related bits
* Thu Dec  9 2010 mrdocs@opensuse.org
- 1.3.9 release
  + 60+ bug fixes
  + addtional templates
* Thu Mar 25 2010 mrdocs@opensuse.org
- update to 1.3.3.14
- drop the implicit patch as its now upstream
* Fri Jul 31 2009 coolo@novell.com
- fix build
* Tue Apr 28 2009 mrdocs@opensuse.org
- drop fdupes it breaks the help browser
- update to 1.3.3.13
- make %%jobs can break builds just use make
* Mon Dec  8 2008 dmueller@suse.de
- update to 1.3.3.12 (released tarball):
  * Several fixes and improvements to text frames and the Story Editor.
  * Some additional scripts have been added to enhance functionality.
  * More translation and documentation updates.
  * Several fixes to protect against possible crashes.
  * Improvements to the Scripter to enable more features.
* Thu Oct  9 2008 meissner@suse.de
- added stdlib.h, string.h
- run %%fdupes
* Mon Jun  2 2008 crrodriguez@suse.de
- needs fno-strict-aliasing
* Wed Apr 16 2008 dmueller@suse.de
- update to 1.3.3.12svn:
  * http://bugs.scribus.net/changelog_page.php
- add help files back (bnc#379906)
* Mon Apr 14 2008 dmueller@suse.de
- fix build against cmake 2.6
- sync buildrequires with the community package
* Sun Jan 13 2008 dmueller@suse.de
- update to 1.3.3.11:
  * Special characters in plain text files aren't imported
  correctly
  * Change text string in PDF export dialog
* Tue Jan  8 2008 stbinner@suse.de
- update to 1.3.3.10, many bugfixes - for details see ChangeLog
* Wed Jun 27 2007 dmueller@suse.de
- build against cmake to fix various issues
* Wed Jun 13 2007 ltinkl@suse.cz
- update to 1.3.3.9 bugfix release
  - many bugfixes
  - more translation updates
  - improvements to the SVG importer
  - improvements to PDF forms
- update to 1.3.3.8
  - many bugfixes
  - more translation updates
  - improvements to the SVG importer
  - improvements to the Open Document Draw importer
  - improvements to PDF forms
* Mon Apr 23 2007 pgajdos@suse.cz
- fixed doc paths in spec file
* Mon Mar 12 2007 pgajdos@suse.cz
- fixed gcc warnings in beta version:
  * program uses possibly exploitable format strings
    (format-not-literal.patch)
  * program compares a char* pointer with string literal
    (string-literal-comparsion.patch)
  * added CFLAG -fno-strict-aliasing inside scribus.spec
* Thu Mar  8 2007 pgajdos@suse.cz
- fixed 'warning: comparsion with string literal' (#233016, #228963)
- string-literal-comparsion.patch
* Sun Jan 28 2007 stbinner@suse.de
- Updated to bugfix release 1.3.3.7
* Thu Nov  9 2006 sbrabec@suse.cz
- Fixed python detection (#213668).
* Sat Nov  4 2006 stbinner@suse.de
- fix build for < 10.1
* Wed Oct 18 2006 sbrabec@suse.cz
- Updated to version 1.3.3.4:
  * Purely a bug fix release.
  * Translations updated.
* Tue Aug  8 2006 stbinner@suse.de
- update to version 1.3.3.3 "stable usable development version"
  * Fix borked color names and wrong Bitstream Vera rendering
  * Many crash und other minor bug fixes
  * Several translation updates
* Thu Jul 13 2006 stbinner@suse.de
- fix build for <10.1
* Wed May 31 2006 adrian@suse.de
- update to version 1.3.3.2 "stable usable development version"
  * more than 200 bugs and feature requests got implemented
  * fix for pdf export using Adobe Reader 7.x
  * new language translations
* Mon May 29 2006 schwab@suse.de
- Don't strip binaries.
* Mon Feb 20 2006 sbrabec@suse.cz
- Export dynamic symbols from scribus binary (#148279).
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Jan 20 2006 schwab@suse.de
- Don't strip binaries.
* Tue Jan 10 2006 sbrabec@suse.cz
- Re-enabled desktop file translation.
* Fri Jan  6 2006 sbrabec@suse.cz
- Updated to version 1.2.4.1.
* Thu Jan  5 2006 sbrabec@suse.cz
- Updated to version 1.2.4.
* Tue Jan  3 2006 sbrabec@suse.cz
- Suggest AdobeICCProfiles.
* Wed Dec  7 2005 sbrabec@suse.cz
- Search for ICC profiles in subdirectories.
  http://bugs.scribus.net/view.php?id=2882
* Fri Nov 25 2005 sbrabec@suse.cz
- Fixed devel splitting (#117811).
- Resource /usr/local/share/color/icc.
  http://bugs.scribus.net/view.php?id=2864
- Enabled parallel build.
* Tue Oct 25 2005 sbrabec@suse.cz
- Updated to version 1.2.3.
- Install MIME info files.
* Wed Jul 27 2005 sbrabec@suse.cz
- Provide and obsolete scribus-short-words.
* Wed Jul 13 2005 sbrabec@suse.cz
- Updated to version 1.2.2.1.
- Removed unneeded static modules and .la files for modules.
* Wed Jan 26 2005 sbrabec@suse.cz
- Obsoleted old documentation packages.
* Tue Jan 11 2005 sbrabec@suse.cz
- Updated to version 1.2.1.
* Thu Dec 16 2004 coolo@suse.de
- fix unsermake install
* Wed Sep 15 2004 sbrabec@suse.cz
- Worked-around bi-arch bugs by forcing /usr/lib (#44961).
  http://bugs.scribus.net/bug_view_advanced_page.php?bug_id=0001057
* Sun Sep  5 2004 coolo@suse.de
- fixing build requires
* Tue Aug 31 2004 sbrabec@suse.cz
- Updated to version 1.2.
* Fri Aug 27 2004 sbrabec@suse.cz
- Updated to version 1.2RC1.
* Wed Mar 31 2004 ro@suse.de
- run update_admin to get current libtool macros
- some more configure hackery to adapt to updated kde-macros
  to finally find python on lib64 platforms
* Wed Mar 31 2004 sf@suse.de
- add scribus-1.1.5-c++.diff (#37208)
* Tue Mar 30 2004 sbrabec@suse.cz
- Updated to version 1.1.6.
* Thu Mar  4 2004 sbrabec@suse.cz
- Updated to version 1.1.5.
* Mon Feb 23 2004 sbrabec@suse.cz
- Fixed and turned on CUPS support.
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Fri Aug 22 2003 sbrabec@suse.cz
- Updated to version 1.0.1.
* Fri Aug 15 2003 adrian@suse.de
- install desktop file
* Wed Aug 13 2003 ro@suse.de
- run update_admin (autoreconf in kde-style)
- change prefix/lib to libdir in all Makefile.am
* Tue Aug 12 2003 sbrabec@suse.cz
- Updated to version 1.0.
* Wed Jun 11 2003 ro@suse.de
- add doc-dir to filelist
* Mon Mar 31 2003 ro@suse.de
- fix build on lib64
* Mon Feb 10 2003 sbrabec@suse.cz
- Fix Qt path for biarch.
* Mon Feb 10 2003 sbrabec@suse.cz
- Updated to version 0.9.7.
* Wed Nov 20 2002 sbrabec@suse.cz
- Added new package.
- FHS fixes.
- Aufoconf fixes.
- KDE autoconf fixes.
